@@ -13,11 +13,11 @@ EJS::Template - EJS (Embedded JavaScript) template engine
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -57,7 +57,7 @@ Within C<< <%...%> >>, it is also possible to call C<print()> function:
     i = 2
 
 C<EJS::Template> supports auto-escaping that minimizes the risk of forgetting
-HTML-escape every individual variable. (See L<#Auto-escaping> for more details.)
+HTML-escape every individual variable. (See L</Auto-escaping> for more details.)
 
     # Perl
     my $ejs = EJS::Template->new(escape => 'html'); # Set default escape type
@@ -81,7 +81,7 @@ HTML-escape every individual variable. (See L<#Auto-escaping> for more details.)
 
 Extra white spaces around C<< <% >> and C<< %> >> are appropriately trimmed
 so that the result output will look fairly clean intuitively.
-See L<#Trimming white spaces> for more details.
+See L</Trimming white spaces> for more details.
 
     <ul>
     v-- Indent would make unnecessary space in the output.
@@ -128,12 +128,12 @@ Available configurations are as below:
 Sets the default escape type for all the interpolation tags (C<< <%=...%> >>).
 
 Possible values are: C<'raw'> (default), C<'html'>, C<'xml'>, C<'uri'>, and
-C<'quote'>. See L<#Auto-escaping> for more details.
+C<'quote'>. See L</Auto-escaping> for more details.
 
 =item * engine => ENGINE_CLASS
 
 Sets the JavaScript engine class.
-See L<#JavaScript engines> for more details.
+See L</JavaScript engines> for more details.
 
 =back
 
@@ -141,11 +141,8 @@ See L<#JavaScript engines> for more details.
 
 sub new {
 	my ($class, %config) = @_;
-	
-	return bless {
-		engine => $config{engine} || 'JavaScript::V8',
-		escape => $config{escape} || '',
-	}, $class;
+	my $self = {map {$_ => $config{$_}} qw(engine escape)};
+	return bless $self, $class;
 }
 
 =head2 process
@@ -387,7 +384,7 @@ In the current version, the data conversion is limited to basic types
 (strings, numbers, hashes, arrays, and functions), although arbitrarily nested
 structures are allowed.
 
-    EJS::Template::process('sample.ejs', {
+    EJS::Template->process('sample.ejs', {
         name => 'World',
         hash => {foo => 123, bar => 456, baz => [7, 8, 9]},
         array => ['a'..'z'],
@@ -400,7 +397,7 @@ structures are allowed.
 If a blessed reference in Perl is passed to EJS, it is converted into a basic type.
 
 If a Perl subroutine is invoked from inside EJS, the types of the arguments depend
-on the JavaScript engine that is in use internally (See L<#JavaScript Engines>).
+on the JavaScript engine that is in use internally (See L</JavaScript engines>).
 
     # Perl
     sub printRefs {
@@ -511,7 +508,7 @@ ideas and inspirations.
 
 =over 4
 
-=item * Template::Toolkit (a.k.a. TT)
+=item * Template Toolkit (a.k.a. TT)
 
 L<Template::Toolkit>
 
